@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from collections import MutableSequence
+from collections.abc import MutableSequence
 
 import numpy as np
 
